/****************************************************************************
*                             MESSTASK.H
*      Header file to MESSTASK.C
*      demonstrates continuous measurement using MDD 
*	   and transfer to the PC via DMA.
*	   Part of SORCUS Application Note 067
*
*              version                       : 1.A.
*              creation                      : 16.08.1999
*              last change                   : 16.08.1999
*              author                        : M. Sailer
*
*    (c) by SORCUS Computer GmbH Heidelberg 1999
****************************************************************************/

/****************************************************************************
*  Description: This program measures continuously analog input from 
*        16 channels of the module M-AD12-16 and puts the data into buffers.
*        If the buffer has reached a limit, the task initializes DMA transfer
*		 to the PC.
*
*  Compiler: Borland C 3.1
*
*  hardware requirements: MODULAR-4/486 board, SPB-module M-AD12-16
*
*  software requirements: This program requires the library ML8RTBIB.LIB
*        and the header ML8RTBIB.H. The operating system OSX on the
*        MODULAR-4/486 board must be ML8-3B.00x or greater
****************************************************************************/
/****************************************************************************
*  history:
*        1.A. 16.08.1999 14:00; MS
*        - creation of the file
****************************************************************************/

#ifndef byte
	#define byte        unsigned char
#endif
#ifndef ushort
	#define ushort      unsigned short
#endif
#ifndef ulong
	#define ulong       unsigned long
#endif

#define TRUE           1
#define FALSE          0

#define INSTALLED      	0
#define MDD_ERROR      	1
#define MEMORY_ERROR   	2
#define MEM_RANGE_ERROR	3
#define RUNNING	        4
#define CANCELLED       5

#define	M_AD12_16_SLOT	1

#define	MESSTASK_PROGNO	0x402
#define	MESSTASK_TASKNO	48

struct pdt_type                        /* Program-Descriptor-Tab. (PDT)    */
    {
     byte     typ;                     /* type of PDT                      */
     byte     lengt;                   /* length of PDT-header             */
     ushort   proc_num;                /* number of procedures             */
     ushort   prg_number;              /* program-number                   */
     byte     version;                 /* program-version                  */
     byte     revision;                /* program-revision                 */
     byte     cpu_type;                /* processor-type                   */
     byte     coproz_type;             /* co-processor-type                */
     byte     language;                /* programming language             */
     byte     prg_type;                /* program-type                     */

     ushort   flags;                   /* installation-flags               */
     ushort   interrupt_num;           /* number of the used interrupt     */

     ulong    data_adr;                /* start-address of data-area       */
     ulong    data_size;               /* size of data-area                */
     ulong    data_min;                /* minimum size of data-area        */
				       /* for this program                 */
     ulong    data_max;                /* maximum size of data-area        */
				       /* for the program                  */

     ulong    parameter_adr;           /* address of parameter-area        */
     ushort   parameter_size;          /* number of parameters             */

     ulong    hyper_adr;               /* start-addr.of hypertext-area     */
     ushort   res1;
     ulong    res2;

     void* PFAR main_proc;          /* address of main-proc. (Task)     */
     void* PFAR auto_init;          /* address of auto-init-proced.     */
     void* PFAR start;              /* address of start-procedure       */
     void* PFAR stop;               /* address of stop-procedure        */
     void* PFAR callback;           /* address of DMA callback function */
    } pdt;

typedef struct
    {                                  /* parameters                       */
#ifdef RT
     tdt_type tdt;                     /* reservation for TDT              */
#endif				       /* used with realtime program       */           */

   USHORT      usStatus;   	/* status of program:		   */
	ULONG			ulNumDMABytes;
	ULONG			ulNumSamples;
	HMDD8			hMDD;			
	USHORT		usBufferNum;
	USHORT		usBufferIndex [2];
	USHORT		usBufferState [2];
	BUFFERLIST	rcBufferList [2];
	UCHAR			*pucMemoryBuffer [2];
    } par_type_MESSTASK;

enum
{
	BUFFERSTATE_FREE,
	BUFFERSTATE_IN_USE,
	BUFFERSTATE_TRANSFER
};

#define	SRQWORD_MDD_ERROR		0x0080
#define SRQWORD_TRANSFER_ERROR	0x0180

